/**
 * Copyright 2005 The Apache Software Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/*
 * $Id: TestStringURL.java 4486 2005-12-19 20:32:21Z kangas $
 */

package org.apache.nutch.net;

import java.io.*;
import java.util.*;
import java.util.logging.Level;
import junit.framework.TestCase;

/** 
 * Simple test suite for WhitelistURLFilter/WhitelistWriter
 * We simulate the following:
 *
 * nutch org.apache.nutch.net.WhitelistWriter /tmp/foo < whitelist.txt
 * nutch org.apache.nutch.net.WhitelistWriter /tmp/foo < whitelist.txt
 *
 * (1/2006 kangas)
 */
public class TestWhitelistURLFilter extends TestCase {
  // Test whitelist entries
  static final String[] WHITELIST_TXT = {
    "www.bryantpark.org=/calendar/events/.+",
    "petescandystore.com=/newmusic/newshows.html",
    "www.playbill.com=/events/event_detail/.+ /events/3/.+"
  };
  
  // URLs to test. Leading +/- indicates whether it should succeed or fail
  static final String[] URLS_TXT = {
    "+http://www.bryantpark.org/calendar/events/111",
    "-http://bryantpark.org/calendar/events/999",
    "+http://www.bryantpark.org/calendar/events/111?fun=yes",
    "-http://petescandystore.com/newmusic/new",
    "+http://www.petescandystore.com/newmusic/newshows.html",
    "+http://petescandystore.com/newmusic/newshows.html"
  };
  
  private File tempDir;
  
  public TestWhitelistURLFilter(String name) { 
    super(name); 
  }
  
  /** Write WHITELIST_TXT to disk via WhitelistWriter */
  protected void setUp() throws Exception {
    tempDir = File.createTempFile("testwhitelist", "");
    String dirname = tempDir.getAbsolutePath();
    
    WhitelistWriter.writeMapFile(Arrays.asList(WHITELIST_TXT), dirname, true);
  }
  
  /** Run URLS_TXT through filter */
  public void testFilter() throws Exception {
    String dir = tempDir.getAbsolutePath();
    WhitelistURLFilter filter = new WhitelistURLFilter(dir, false);
    
    for (int i=0; i < URLS_TXT.length; i++) {
      String line = URLS_TXT[i];
      boolean shouldSucceed = line.startsWith("+");
      String url = line.substring(1);
      
      System.out.println("TESTING "+line);
      String out = filter.filter(url);
      
      if (shouldSucceed) {
	assertEquals(url, out);
      } else {
	assertNull(out);
      }
    }
  }

  /** Remove whitelist dir from disk */
  protected void tearDown() {
    File[] deletes = tempDir.listFiles();
    for (int i=0; i < deletes.length; i++) {
      deletes[i].delete();
    }
    tempDir.delete();
  }
  
}

